==> stats_V2.4_2011-03-30_26.tar.gz: stats_V2.4_2011-03-30_26/stats/edituser.php <==
<?
require_once(dirname(__FILE__) . "/lib/defines.php");

/*
echo "<pre>";
var_dump($_REQUEST);
echo "</pre>";
*/


function extract_var($varname,$value){
  if(!is_array($value)){
    preg_match('/^'.$varname.'_(.*)$/', $value, $matches);
    if(isset($matches[1])){
      return $matches[1];
    }
  }
  return false;
}


function gen_select($array,$name,$selected){
  $select = '<select name="'.$name.'" id="'.$name.'" size="1">'."\n";
  foreach($array as $key => $val){
    $select .= "\t".'<option value="'.$val.'"';
    if( $key == $selected)
      $select .= ' selected ';
    $select .= '>';
    $select .= "$key</option>\n";
  }
  return $select .= '</select>';
}

function update_user($userid,$db,$userinfos=''){
  global $message2;
  if(is_array($userinfos) && $userid == $_SESSION['userinfos']["userid"]){
    $_SESSION['userinfos']['discols']=$userinfos['discols'];
    $_SESSION['userinfos']['search']=$userinfos['search'];
    //Ok update session:
    $message2.=' and current session updated';
  }
  $db-> query("UPDATE ".DB_TABLEUSERS." set updated=NOW() WHERE id='$userid' ");
}

function changepassword($newpassword){
  $db=DbConnect();
  //$db -> Halt_On_Error = "no";
  //set good userid
  if($_REQUEST['userid'] && $_SESSION['admin'] == 1 )
    $userid=$_REQUEST['userid'];
  else
    $userid=$_SESSION['userinfos']["userid"];
  //User exists ?
  $db->query("SELECT * FROM ".DB_TABLEUSERS." WHERE id='$userid' ");
  if($db -> num_rows() != 1 )
    return $message1='<font color="red">Error : user not found</font>';
  $db -> next_record();
  $userdata=$db -> Record;
  if($userdata["password"]!==sha1($newpassword."+".SALT)){
    $db -> query("UPDATE ".DB_TABLEUSERS." set password=SHA1('$newpassword+".SALT."') WHERE id='$userid' ");
    if($db->affected_rows() === 1){
      update_user($userid,$db);
      return $message1='Password changed for user : '.$userdata['username'];
    }
    else
      return $message1='<font color="red">Error : Unable to update password</font>';   
  }else{
    return $message1='New password is the same as the old one';
  }
}

function getuser($userid){
  $db=DbConnect();
  $db -> Halt_On_Error = "no";
  $db->query("SELECT id,username,admin,userinfos from ".DB_TABLEUSERS." where id='$userid'");
  if($db -> num_rows() != 1 )
    return false;
  $db -> next_record();
  return $db -> Record; 
}


//Change Password ?
if(isset($_POST["change_password"]) && (USER_CAN_CHPASS != 0 || $_SESSION['admin'] == 1 ) ){
  if($_POST["password"] !== ""){  
    if($_POST["password"] === $_POST["password2"]){     
      $message1=changepassword($_POST["password"]);          
    }else{
      $message1='<font color="red">Error : Passwords given are not identical</font>';
    }
  }else{
    $message1='<font color="red">Error :Password can\'t be empty</font>';
  }
}

//Change Userinfos ?
if(isset($_POST["change_userinfos"]) && $_SESSION['admin'] == 1 ){
  if($_REQUEST['userid'] && $_SESSION['admin'] == 1 )
    $userid=$_REQUEST['userid'];
  else
    $userid=$_SESSION['userinfos']["userid"];
  $db=DbConnect();
  $db -> Halt_On_Error = "no";
  $userinfos_array=serialize(array(
    'search'=>$_REQUEST['search'],
    'discols'=>$_REQUEST['discols'],
  ));

  $db -> query("UPDATE ".DB_TABLEUSERS." set userinfos='$userinfos_array', admin='".$_REQUEST['admin']."' WHERE id='$userid' ");
  if($db->affected_rows() === 1){
    //Update session , usefull for test :
    $message2='User settings changed ';
    update_user($userid,$db,unserialize($userinfos_array));
  }else
    $message2='User settings unchanged';
}

//Delete USER ?
if( isset($_REQUEST["delete_user"]) && $_SESSION['admin'] == 1 &&
    $_REQUEST['userid'] != $_SESSION['userinfos']['userid'] &&
    $userdata=getuser($_REQUEST['userid'])
){
  if( $_REQUEST['delete_user'] == 'confirmed'){
    //Realy delete user:
    $db=DbConnect();
    $db -> Halt_On_Error = "no";
    $db -> query("DELETE FROM ".DB_TABLEUSERS." WHERE id='".$_REQUEST['userid']."' LIMIT 1 ");
    ?>
    <!-- Report Delete -->
    <center>
    <table width="60%" border="0"><tr>
    <td colspan="2" align="center">
    <h1>User <?=$userdata['username']?> has been deleted</h1>
    </td></tr>
    <tr>
    <td align="center">
    </td>
    <td align="center">
    <a href="?s=14" title="Back to Users list"><img src="images/back.png" border="0"><br>Continue</a>
    </td>
    </tr></table></center>
    <? return;    
  }else{
    ?>
    <!-- Confirmation-->
    <center>
    <table width="60%" border="0"><tr>
    <td colspan="2" align="center">
    <h1>You are about to delete user : <?=$userdata['username']?></h1>
    </td></tr>
    <tr>
    <td align="center">
    <a href="?s=<?=$s.'&userid='.$_REQUEST['userid'].'&delete_user=confirmed'?>" title="Delete User"><img src="images/delete.png" border="0"><br>Proceed!</a>
    </td>
    <td align="center">
    <a href="?s=<?=$s.'&userid='.$_REQUEST['userid']?>" title="Back to User editition"><img src="images/back.png" border="0"><br>Cancel</a>
    </td>
    </tr></table></center>
    <? return;
  }


}


?>


<center>
<FORM METHOD=POST ACTION="?s=<?=$s?>">
<?
//Set userid on form
if( $_SESSION['admin'] == 1 &&
    isset($_REQUEST['userid']) &&
    $userdata=getuser($_REQUEST['userid'])){ 
    $editingotheruser=true;    
?>
  <INPUT TYPE="hidden" NAME="userid" value="<?=$_REQUEST['userid']?>">
<?}else{
  //$_SESSION['userinfos']['userid'];
  $userdata=getuser($_SESSION['userinfos']['userid']);
}
//Unserialize userinfos:
$userinfos=unserialize($userdata["userinfos"]);
//var_dump($userdata);
?>
<b>Editing User : <?=$userdata['username']?></b><br><br>
<INPUT TYPE="hidden" NAME="posted" value=1>
	<table class="bar-status" width="450" border="0" cellspacing="1" cellpadding="2" align="center">
		<tbody>
<?



$colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
$INPUTS=array(
  "password"  => array('desc'=>"New Password:",'type'=>"password",'size'=>'18'),
  "password2" => array('desc'=>"Confirm Password:",'type'=>"password",'size'=>'18'),
);
foreach($INPUTS as $varname => $description){
$cpt++;


?>
		<tr>
				<td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][0]?>">			
					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?=$description['desc']?></b></font>
				</td>				
				<td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][1]?>">
				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;&nbsp;
          <INPUT TYPE="<?=$description['type']?>" NAME="<?=$varname?>" value="<?=$$varname?>" size="<?=$description['size']?>"></td>
  				</tr>
        </table></td>
			</tr>			
	<?
} 
$cpt++;
?>
  <td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][0]?>"> </td>
	  <td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][1]?>">
		  <input type="submit" align="top" border="0" name="change_password" value="Change Password" />
		  </td>
	  </tr>
  </tbody>
 </table>


<?
if($message1)
  echo "$message1";
?>
<br>
<br>
<?
if ($_SESSION['admin'] == 1) {

?>

	<table class="bar-status" width="450" border="0" cellspacing="1" cellpadding="2" align="center">
		<tbody>
<?


//Generate array from GLOBALS
$discols_array['default']='';
$search_array['default']='';

foreach($GLOBALS as $key=>$value){
  $res_cols=extract_var('_FG_TABLE_COL',$key);
  $res_search=extract_var('_VCHAR_SEARCH',$key);
  if($res_cols)
    $discols_array[$res_cols]=$res_cols;
  if($res_search)
    $search_array[$res_search]=$res_search;
}

$colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
$INPUTS=array(
  "search"  => array('desc'=>"Search View :",'type'=>"select",'value'=> $userinfos['search'],'values'=>$search_array),
  "discols"  => array('desc'=>"Log View :",'type'=>"select",'value'=> $userinfos['discols'],'values'=>$discols_array),
  "admin" => array('desc'=>"Administrator :",'type'=>"checkbox",'value'=> $userdata['admin']==1?'checked':''),
);
foreach($INPUTS as $varname => $description){
$cpt++;


?>
		<tr>
				<td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][0]?>">			
					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?=$description['desc']?></b></font>
				</td>				
				<td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][1]?>">
				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr>
          <?switch ($description['type']) {
            case "select":?><td>&nbsp;&nbsp;
          <?=gen_select($description['values'],$varname,$description['value']);?></td>
            <?break;
            case "checkbox":?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?=$description['type']?>" NAME="<?=$varname?>" value="1" <?=$description['value']?>"></td>
            <?break;
            default:?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?=$description['type']?>" NAME="<?=$varname?>" value="<?=$description['value']?>" size="<?=$description['size']?>"></td>
            <?break;?>
          <?}?>
  				</tr>
        </table></td>
			</tr>			
	<?
} 
$cpt++;
?>
     <td class="bar-search" align="left" bgcolor="#<?=$colors[$cpt%2][0]?>"> </td>
				<td class="bar-search" align="right" bgcolor="#<?=$colors[$cpt%2][1]?>">
					<input type="submit" align="top" border="0" name="change_userinfos" value="Change user settings" />
	  			</td>
    		</tr>
		</tbody></table>
	</FORM>
<? 
}?>
<br>
<?
if($message2)
  echo "$message2";
else
  echo "<br>";
?>
<table width="40%" border="0"><tr>
<td align="left"><?
if(isset($editingotheruser) &&
   $_SESSION['admin'] == 1 &&
   $_REQUEST['userid'] != $_SESSION['userinfos']['userid'] ){ ?>
<a href="?s=<?=$s?>&delete_user=yes&userid=<?=$_REQUEST['userid']?>" title="Delete User"><img src="images/delete.png" border="0"></a>
<?}?>
</td>
<td align="right"><?
if(isset($editingotheruser) &&
   $_SESSION['admin'] == 1 ) {?>
   
<a href="?s=14" title="Return to User list"><img src="images/back.png" border="0"></a><?
}?>
</td>
</tr>
</table>

</center>

==> stats_V2.7_2014-11-05_52.tar.gz: stats_V2.7_2014-11-05_52/stats/edituser.php <==
<?php
require_once(dirname(__FILE__) . "/lib/defines.php");

/*
echo "<pre>";
var_dump($_REQUEST);
echo "</pre>";
*/


function extract_var($varname,$value){
  if(!is_array($value)){
    preg_match('/^'.$varname.'_(.*)$/', $value, $matches);
    if(isset($matches[1])){
      return $matches[1];
    }
  }
  return false;
}


function gen_select($array,$name,$selected){
  $select = '<select name="'.$name.'" id="'.$name.'" size="1">'."\n";
  foreach($array as $key => $val){
    $select .= "\t".'<option value="'.$val.'"';
    if( $key == $selected)
      $select .= ' selected ';
    $select .= '>';
    $select .= "$key</option>\n";
  }
  return $select .= '</select>';
}

function update_user($userid,$db,$userinfos=''){
  global $message2;
  if(is_array($userinfos) && $userid == $_SESSION['userinfos']["userid"]){
    $_SESSION['userinfos']['discols']=$userinfos['discols'];
    $_SESSION['userinfos']['search']=$userinfos['search'];
    //Ok update session:
    $message2.=' and current session updated';
  }
  $db-> query("UPDATE ".DB_TABLEUSERS." set updated=NOW() WHERE id='$userid' ");
}

function changepassword($newpassword){
  $db=DbConnect();
  //$db -> Halt_On_Error = "no";
  //set good userid
  if($_REQUEST['userid'] && $_SESSION['admin'] == 1 )
    $userid=$_REQUEST['userid'];
  else
    $userid=$_SESSION['userinfos']["userid"];
  //User exists ?
  $db->query("SELECT * FROM ".DB_TABLEUSERS." WHERE id='$userid' ");
  if($db -> num_rows() != 1 )
    return $message1='<font color="red">Error : user not found</font>';
  $db -> next_record();
  $userdata=$db -> Record;
  if($userdata["password"]!==sha1($newpassword."+".SALT)){
    $db -> query("UPDATE ".DB_TABLEUSERS." set password=SHA1('$newpassword+".SALT."') WHERE id='$userid' ");
    if($db->affected_rows() === 1){
      update_user($userid,$db);
      return $message1='Password changed for user : '.$userdata['username'];
    }
    else
      return $message1='<font color="red">Error : Unable to update password</font>';   
  }else{
    return $message1='New password is the same as the old one';
  }
}

function getuser($userid){
  $db=DbConnect();
  $db -> Halt_On_Error = "no";
  $db->query("SELECT id,username,admin,userinfos from ".DB_TABLEUSERS." where id='$userid'");
  if($db -> num_rows() != 1 )
    return false;
  $db -> next_record();
  return $db -> Record; 
}


//Change Password ?
if(isset($_POST["change_password"]) && (USER_CAN_CHPASS != 0 || $_SESSION['admin'] == 1 ) ){
  if($_POST["password"] !== ""){  
    if($_POST["password"] === $_POST["password2"]){     
      $message1=changepassword($_POST["password"]);          
    }else{
      $message1='<font color="red">Error : Passwords given are not identical</font>';
    }
  }else{
    $message1='<font color="red">Error :Password can\'t be empty</font>';
  }
}

//Change Userinfos ?
if(isset($_POST["change_userinfos"]) && $_SESSION['admin'] == 1 ){
  if($_REQUEST['userid'] && $_SESSION['admin'] == 1 )
    $userid=$_REQUEST['userid'];
  else
    $userid=$_SESSION['userinfos']["userid"];
  $db=DbConnect();
  $db -> Halt_On_Error = "no";
  $userinfos_array=serialize(array(
    'search'=>$_REQUEST['search'],
    'discols'=>$_REQUEST['discols'],
  ));

  $db -> query("UPDATE ".DB_TABLEUSERS." set userinfos='$userinfos_array', admin='".$_REQUEST['admin']."' WHERE id='$userid' ");
  if($db->affected_rows() === 1){
    //Update session , usefull for test :
    $message2='User settings changed ';
    update_user($userid,$db,unserialize($userinfos_array));
  }else
    $message2='User settings unchanged';
}

//Delete USER ?
if( isset($_REQUEST["delete_user"]) && $_SESSION['admin'] == 1 &&
    $_REQUEST['userid'] != $_SESSION['userinfos']['userid'] &&
    $userdata=getuser($_REQUEST['userid'])
){
  if( $_REQUEST['delete_user'] == 'confirmed'){
    //Realy delete user:
    $db=DbConnect();
    $db -> Halt_On_Error = "no";
    $db -> query("DELETE FROM ".DB_TABLEUSERS." WHERE id='".$_REQUEST['userid']."' LIMIT 1 ");
    ?>
    <!-- Report Delete -->
    <center>
    <table width="60%" border="0"><tr>
    <td colspan="2" align="center">
    <h1>User <?php echo $userdata['username']?> has been deleted</h1>
    </td></tr>
    <tr>
    <td align="center">
    </td>
    <td align="center">
    <a href="?s=14" title="Back to Users list"><img src="images/back.png" border="0"><br>Continue</a>
    </td>
    </tr></table></center>
    <?php return;    
  }else{
    ?>
    <!-- Confirmation-->
    <center>
    <table width="60%" border="0"><tr>
    <td colspan="2" align="center">
    <h1>You are about to delete user : <?php echo $userdata['username']?></h1>
    </td></tr>
    <tr>
    <td align="center">
    <a href="?s=<?php echo $s.'&userid='.$_REQUEST['userid'].'&delete_user=confirmed'?>" title="Delete User"><img src="images/delete.png" border="0"><br>Proceed!</a>
    </td>
    <td align="center">
    <a href="?s=<?php echo $s.'&userid='.$_REQUEST['userid']?>" title="Back to User editition"><img src="images/back.png" border="0"><br>Cancel</a>
    </td>
    </tr></table></center>
    <?php return;
  }


}


?>


<center>
<FORM METHOD=POST ACTION="?s=<?php echo $s?>">
<?php
//Set userid on form
if( $_SESSION['admin'] == 1 &&
    isset($_REQUEST['userid']) &&
    $userdata=getuser($_REQUEST['userid'])){ 
    $editingotheruser=true;    
?>
  <INPUT TYPE="hidden" NAME="userid" value="<?php echo $_REQUEST['userid']?>">
<?php }else{
  //$_SESSION['userinfos']['userid'];
  $userdata=getuser($_SESSION['userinfos']['userid']);
}
//Unserialize userinfos:
$userinfos=unserialize($userdata["userinfos"]);
//var_dump($userdata);
?>
<b>Editing User : <?php echo $userdata['username']?></b><br><br>
<INPUT TYPE="hidden" NAME="posted" value=1>
	<table class="bar-status" width="450" border="0" cellspacing="1" cellpadding="2" align="center">
		<tbody>
<?php



$colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
$INPUTS=array(
  "password"  => array('desc'=>"New Password:",'type'=>"password",'size'=>'18'),
  "password2" => array('desc'=>"Confirm Password:",'type'=>"password",'size'=>'18'),
);
foreach($INPUTS as $varname => $description){
$cpt++;


?>
		<tr>
				<td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][0]?>">			
					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?php echo $description['desc']?></b></font>
				</td>				
				<td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr><td>&nbsp;&nbsp;
          <INPUT TYPE="<?php echo $description['type']?>" NAME="<?php echo $varname?>" value="<?php echo $$varname?>" size="<?php echo $description['size']?>"></td>
  				</tr>
        </table></td>
			</tr>			
	<?php
} 
$cpt++;
?>
  <td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][0]?>"> </td>
	  <td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
		  <input type="submit" align="top" border="0" name="change_password" value="Change Password" />
		  </td>
	  </tr>
  </tbody>
 </table>


<?php
if($message1)
  echo "$message1";
?>
<br>
<br>
<?php
if ($_SESSION['admin'] == 1) {

?>

	<table class="bar-status" width="450" border="0" cellspacing="1" cellpadding="2" align="center">
		<tbody>
<?php


//Generate array from GLOBALS
$discols_array['default']='';
$search_array['default']='';

foreach($GLOBALS as $key=>$value){
  $res_cols=extract_var('_FG_TABLE_COL',$key);
  $res_search=extract_var('_VCHAR_SEARCH',$key);
  if($res_cols)
    $discols_array[$res_cols]=$res_cols;
  if($res_search)
    $search_array[$res_search]=$res_search;
}

$colors = array ( 1 => array ('555577','cddeff'), 0 => array('000033','acbdee'));
$INPUTS=array(
  "search"  => array('desc'=>"Search View :",'type'=>"select",'value'=> $userinfos['search'],'values'=>$search_array),
  "discols"  => array('desc'=>"Log View :",'type'=>"select",'value'=> $userinfos['discols'],'values'=>$discols_array),
  "admin" => array('desc'=>"Administrator :",'type'=>"checkbox",'value'=> $userdata['admin']==1?'checked':''),
);
foreach($INPUTS as $varname => $description){
$cpt++;


?>
		<tr>
				<td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][0]?>">			
					<font face="verdana" size="1" color="#ffffff"><b>&nbsp;&nbsp;<?php echo $description['desc']?></b></font>
				</td>				
				<td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
				<table width="100%" border="0" cellspacing="0" cellpadding="0"><tr>
          <?php switch ($description['type']) {
            case "select":?><td>&nbsp;&nbsp;
          <?php echo gen_select($description['values'],$varname,$description['value']);?></td>
            <?php break;
            case "checkbox":?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?php echo $description['type']?>" NAME="<?php echo $varname?>" value="1" <?php echo $description['value']?>"></td>
            <?php break;
            default:?><td>&nbsp;&nbsp;
          <INPUT TYPE="<?php echo $description['type']?>" NAME="<?php echo $varname?>" value="<?php echo $description['value']?>" size="<?php echo $description['size']?>"></td>
            <?php break;?>
          <?php }?>
  				</tr>
        </table></td>
			</tr>			
	<?php
} 
$cpt++;
?>
     <td class="bar-search" align="left" bgcolor="#<?php echo $colors[$cpt%2][0]?>"> </td>
				<td class="bar-search" align="right" bgcolor="#<?php echo $colors[$cpt%2][1]?>">
					<input type="submit" align="top" border="0" name="change_userinfos" value="Change user settings" />
	  			</td>
    		</tr>
		</tbody></table>
	</FORM>
<?php 
}?>
<br>
<?php
if($message2)
  echo "$message2";
else
  echo "<br>";
?>
<table width="40%" border="0"><tr>
<td align="left"><?php
if(isset($editingotheruser) &&
   $_SESSION['admin'] == 1 &&
   $_REQUEST['userid'] != $_SESSION['userinfos']['userid'] ){ ?>
<a href="?s=<?php echo $s?>&delete_user=yes&userid=<?php echo $_REQUEST['userid']?>" title="Delete User"><img src="images/delete.png" border="0"></a>
<?php }?>
</td>
<td align="right"><?php
if(isset($editingotheruser) &&
   $_SESSION['admin'] == 1 ) {?>
   
<a href="?s=14" title="Return to User list"><img src="images/back.png" border="0"></a><?php
}?>
</td>
</tr>
</table>

</center>
